<?php
include 'partials/header.php';

// Verificăm dacă utilizatorul este autentificat
if (!isset($_SESSION['user-id'])) {
    // Dacă utilizatorul nu este autentificat, îl redirecționăm către pagina de autentificare
    header('Location: signin.php');
    exit();
}

$user_id = $_SESSION['user-id'];

// Interogare pentru a obține informațiile utilizatorului și calea către imaginea de profil din baza de date
$user_query = "SELECT firstname, lastname, grad, image_profile FROM users WHERE id = ?";
$stmt = mysqli_prepare($connection, $user_query);
mysqli_stmt_bind_param($stmt, "i", $user_id);
mysqli_stmt_execute($stmt);
$user_result = mysqli_stmt_get_result($stmt);

// Verificăm dacă am obținut un rând rezultat
if ($user_row = mysqli_fetch_assoc($user_result)) {
    // Extragem numele, gradul și calea către imaginea de profil a utilizatorului
    $firstname = $user_row['firstname'];
    $lastname = $user_row['lastname'];
    $grad = $user_row['grad'];
    $user_profile_image = $user_row['image_profile'];
}

// Mesaj de eroare/succes
$message = '';
$messageClass = '';

// Verificăm dacă formularul pentru adăugarea anunțului a fost trimis
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['title'], $_POST['content'])) {
    // Validăm datele trimise din formular
    $title = $_POST['title'];
    $content = $_POST['content'];

    if (empty($title) || empty($content)) {
        $message = 'Completați toate câmpurile!';
        $messageClass = 'error';
    } else {
        // Salvăm datele în baza de date
        $announcement_query = "INSERT INTO announcements (title, content, user_id) VALUES (?, ?, ?)";
        $stmt = mysqli_prepare($connection, $announcement_query);
        mysqli_stmt_bind_param($stmt, "ssi", $title, $content, $user_id);

        if (mysqli_stmt_execute($stmt)) {
            $message = 'Anunțul a fost adăugat cu succes!';
            $messageClass = 'success';
        } else {
            $message = 'A apărut o eroare. Vă rugăm să încercați din nou mai târziu!';
            $messageClass = 'error';
        }

        mysqli_stmt_close($stmt);
    }
}

// Verificăm dacă formularul pentru modificarea gradului utilizatorului a fost trimis
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['selected_user'], $_POST['selected_grad'])) {
    $selected_user_id = $_POST['selected_user'];
    $selected_grad = $_POST['selected_grad'];

    // Actualizăm gradul utilizatorului în baza de date
    $update_query = "UPDATE users SET grad = ? WHERE id = ?";
    $stmt = mysqli_prepare($connection, $update_query);
    mysqli_stmt_bind_param($stmt, "si", $selected_grad, $selected_user_id);

    if (mysqli_stmt_execute($stmt)) {
        $message = 'Gradul utilizatorului a fost modificat cu succes!';
        $messageClass = 'success';
    } else {
        $message = 'A apărut o eroare. Vă rugăm să încercați din nou mai târziu!';
        $messageClass = 'error';
    }

    mysqli_stmt_close($stmt);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Announcement Form</title>
    <!-- CSS -->
    <link rel="stylesheet" href="css/style.css">
    <style>
        /* Stilizare pentru formularul de anunț */
        .form-container {
            max-width: 600px;
            margin: 20px auto;
            padding: 20px;
            border-radius: 10px;
            background-color: #f8f9fa;
        }

        .form-group {
            margin-bottom: 20px;
        }

        .form-group label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
        }

        .form-group input[type="text"],
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
        }

        .form-group textarea {
            height: 150px;
        }

        .message {
            padding: 10px;
            margin-bottom: 20px;
            border-radius: 5px;
            font-weight: bold;
        }

        .success {
            background-color: #d4edda;
            color: #155724;
        }

        .error {
            background-color: #f8d7da;
            color: #721c24;
        }
    </style>
</head>
<body>
    <!-- Dashboard -->
    <div class="dashboard">
        <!-- Menu -->
        <div class="menu flex-c">
            <div class="logo">
                <div class="icon">
                    <ion-icon name="logo-trello"></ion-icon>
                </div>
            </div>
            <div class="navigation">
                <div class="icon">
                    <a href="feedback.php" class="icon" style="text-decoration: none; color: inherit;">
                        <div>
                            <ion-icon name="filter-circle-outline"></ion-icon>
                        </div>
                    </a>
                </div>
                <div class="icon">
                    <a href="flota_transport.php" class="icon" style="text-decoration: none; color: inherit;">
                        <ion-icon name="file-tray-full-outline"></ion-icon>
                    </a>
                </div>
                <div class="icon">
                    <a href="form.php" class="icon" style="text-decoration: none; color: inherit;">
                        <ion-icon name="mail-unread-outline"></ion-icon>
                    </a>
                </div>
                <div class="icon">
                    <a href="statistics.php" class="icon" style="text-decoration: none; color: inherit;">
                        <div>
                            <ion-icon name="pulse-outline"></ion-icon>
                        </div>
                    </a>
                </div>
                <div class="icon">
                    <ion-icon name="storefront-outline"></ion-icon>
                </div>
            </div>
            <div class="settings">
                <div class="icon">
                    <ion-icon name="settings-outline"></ion-icon>
                </div>
            </div>
        </div>
        <!-- End Menu -->

        <div class="content">
            <!-- Main Content -->
            <div class="main-content">
                <!-- Head -->
                <div class="head flex">
                    <h1>Ce mai e nou 👋</h1>
                    <div class="box flex">
                        <ion-icon name="search-outline"></ion-icon>
                    </div>
                </div>
                <!-- End Head -->

                <!-- Mesaj de eroare/succes -->
                <?php if (!empty($message)): ?>
                    <div class="message <?php echo $messageClass; ?>"><?php echo $message; ?></div>
                <?php endif; ?>
                <!-- End Mesaj -->

                <!-- Formular Anunț -->
                <div class="form-container">
                    <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="POST">
                        <div class="form-group">
                            <label for="title">Title:</label>
                            <input type="text" id="title" name="title" required>
                        </div>
                        <div class="form-group">
                            <label for="content">Content:</label>
                            <textarea id="content" name="content" rows="4" required></textarea>
                        </div>
                        <div class="form-group">
                            <button type="submit">Submit</button>
                        </div>
                    </form>
                </div>
                <!-- End Formular Anunț -->

                <!-- Formular pentru modificarea gradului utilizatorului -->
                <div class="form-container">
                    <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="POST">
                        <div class="form-group">
                            <label for="selected_user">Select User:</label>
                            <select id="selected_user" name="selected_user" required>
                                <?php
                                // Interogare pentru a obține lista utilizatorilor
                                $users_query = "SELECT id, firstname, lastname FROM users";
                                $users_result = mysqli_query($connection, $users_query);

                                // Iterăm prin fiecare utilizator și creăm opțiuni pentru select
                                while ($user = mysqli_fetch_assoc($users_result)) {
                                    echo '<option value="' . $user['id'] . '">' . $user['firstname'] . ' ' . $user['lastname'] . '</option>';
                                }
                                ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="selected_grad">Select Grad:</label>
                            <select id="selected_grad" name="selected_grad" required>
                                <option value="Administrator">Administrator</option>
                                <option value="Departament Financiar">Departament Financiar</option>
                                <option value="Users">Users</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <button type="submit">Modify Grad</button>
                        </div>
                    </form>
                </div>
                <!-- End Formular pentru modificarea gradului utilizatorului -->
            </div>
            <!-- End Main Content -->

  <!-- Profile -->
<div class="profile">
    <div class="title flex">
        <h2 class="heading">Profile</h2>
    </div>
    <div class="user">
        <!-- Afișarea imaginii de profil -->
        <?php
        if (!empty($user_profile_image)) {
            echo '<img src="' . htmlspecialchars($user_profile_image) . '" alt="Profile Picture">';
        } else {
            // Dacă nu există o imagine de profil setată, afișăm o imagine de profil implicită
            echo '<img src="default-profile-image.jpg" alt="Profile Picture">';
        }
        ?>
        <!-- End Afișarea imaginii de profil -->
        <h2><?php echo htmlspecialchars($firstname . ' ' . $lastname); ?></h2>
        
        <!-- Afisare Admin Panel pentru utilizatorii de tip Administrator -->
        <?php if ($grad === "Administrator"): ?>
            <h3><a href="<?php echo ROOT_URL; ?>announcement.php">Admin Panel</a></h3>
        <?php endif; ?>
        
        <!-- Afișăm imaginea corespunzătoare gradului utilizatorului -->
        <?php
        if ($grad === "Administrator") {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Management.png" alt="Administrator" style="width: 156px; height: 35px;"></div>';
        } else if ($grad === "Departament Financiar") {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Staff.png" alt="Departament Financiar" style="width: 156px; height: 35px;"></div>';
        } else {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Member.png" alt="Users" style="width: 156px; height: 35px;"></div>';
        }
        ?>

        <li><a href="<?= ROOT_URL ?>logout.php">Logout</a></li>
    </div>
    <div class="activities">
        <div class="title flex">
            <h2 class="heading">Activity</h2>
            <p>View All ></p>
        </div>
    </div>
</div>
<!-- End Profile -->

        </div>
    </div>
    <!-- End Dashboard -->

    <!-- Script JavaScript pentru încărcarea automată a imaginilor -->
    <script>
        // Așteptăm ca documentul să se încarce complet
        document.addEventListener("DOMContentLoaded", function () {
            // Selectăm input-ul pentru încărcarea fișierului
            var fileInput = document.getElementById('file-input');

            // Selectăm butonul de submit
            var submitButton = document.getElementById('submit-btn');

            // Adăugăm un eveniment pentru când utilizatorul selectează un fișier
            fileInput.addEventListener('change', function () {
                // Verificăm dacă s-a selectat un fișier
                if (fileInput.files.length > 0) {
                    // Simulăm un click pe butonul de submit
                    submitButton.click();
                }
            });
        });
    </script>
    <!-- End Script JavaScript pentru încărcarea automată a imaginilor -->

    <!-- Ion Icons Js -->
    <script type="module" src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.esm.js"></script>
    <script nomodule src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.js"></script>
</body>
</html>
