<?php
// Include baza de date
include 'partials/header.php';

// Verificăm dacă utilizatorul este autentificat
if (!isset($_SESSION['user-id'])) {
    // Dacă utilizatorul nu este autentificat, aruncăm o eroare și încheiem scriptul
    http_response_code(401);
    exit("Unauthorized");
}

// Verificăm dacă sunt trimise datele necesare pentru trimiterea mesajului
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (!isset($_POST['recipient_id']) || !isset($_POST['message'])) {
        // Dacă nu sunt trimise datele necesare, aruncăm o eroare și încheiem scriptul
        http_response_code(400);
        exit("Bad request");
    }

    // Extragem datele trimise prin POST
    $sender_id = $_SESSION['user-id'];
    $recipient_id = $_POST['recipient_id'];
    $message = $_POST['message'];

    // Validăm dacă recipientul există în baza de date
    $recipient_query = "SELECT id FROM users WHERE id = ?";
    $stmt = mysqli_prepare($connection, $recipient_query);
    mysqli_stmt_bind_param($stmt, "i", $recipient_id);
    mysqli_stmt_execute($stmt);
    $recipient_result = mysqli_stmt_get_result($stmt);

    if (mysqli_num_rows($recipient_result) == 0) {
        // Dacă recipientul nu există, aruncăm o eroare și încheiem scriptul
        http_response_code(404);
        exit("Recipient not found");
    }

    // Inserez mesajul în baza de date
    $insert_query = "INSERT INTO messages (sender_id, receiver_id, message) VALUES (?, ?, ?)";
    $stmt = mysqli_prepare($connection, $insert_query);
    mysqli_stmt_bind_param($stmt, "iis", $sender_id, $recipient_id, $message);

    if (mysqli_stmt_execute($stmt)) {
        // Dacă mesajul a fost inserat cu succes, afișăm un mesaj de succes și încheiem scriptul
       echo json_encode(["message" => "Message sent successfully"]);
        exit(); // Ieșim din script după trimiterea mesajului pentru a nu continua să afișăm conținutul paginii
    } else {
        // Dacă a apărut o eroare în timpul inserării mesajului, aruncăm o eroare și încheiem scriptul
        http_response_code(500);
        exit(json_encode(["message" => "Error sending message"]));
    }
}

// Interogare pentru a obține cele mai recente 10 mesaje din baza de date
$message_query = "SELECT u.firstname, u.lastname, m.message FROM messages m INNER JOIN users u ON m.sender_id = u.id ORDER BY m.timestamp DESC LIMIT 10";
$message_result = mysqli_query($connection, $message_query);
?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="stylesheet" href="css/style.css">
<title>Real-Time Chat</title>
<!-- CSS -->
<style>
    body {
        font-family: Arial, sans-serif;
        margin: 0;
        padding: 0;
    }
    .dashboard {
        display: flex;
        flex-direction: column;
        height: 100vh;
    }
    .content {
        display: flex;
        flex: 1;
    }
    .main-content {
        flex: 2;
        padding: 20px;
    }
    .chat-section {
        background-color: #f2f2f2;
        border-radius: 5px;
        padding: 20px;
        margin-bottom: 20px;
    }
    .chat-section h2 {
        margin-top: 0;
    }
    #chat-messages {
        list-style-type: none;
        padding: 0;
        margin: 0;
        overflow-y: scroll;
        height: 300px;
        border: 1px solid #ccc;
        border-radius: 5px;
    }
    #chat-messages li {
        padding: 8px 16px;
        border-bottom: 1px solid #eee;
    }
    #message-input {
        width: calc(100% - 100px);
        margin-right: 10px;
        padding: 8px;
        border-radius: 5px;
        border: 1px solid #ccc;
    }
            .back-button {
            background-color: #6a0dad;
            color: #fff;
            border: none;
            border-radius: 5px;
            padding: 10px 20px;
            font-size: 16px;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        .back-button:hover {
            background-color: #4b0872; /* O nuanta mai inchisa de mov */
        }
    #send-button {
        padding: 8px 16px;
        border: none;
        border-radius: 5px;
        background-color: #007bff;
        color: white;
        cursor: pointer;
    }
    ul#chat-messages {
    color: black;
}
</style>
</head>
<body>
<!-- Dashboard -->
<div class="dashboard">
    <!-- Menu -->
    <?php include 'partials/menu.php'; ?>
    <!-- End Menu -->

    <div class="content">
        <!-- Main Content -->
        <div class="main-content">
            <!-- Head -->
                            <button class="back-button" onclick="window.location.href = 'index.php';">Inapoi</button>
            <div class="head flex">
                <h1>Good Morning 👋</h1>
                <div class="box flex">
                    <ion-icon name="search-outline"></ion-icon>
                </div>
            </div>
            <!-- End Head -->

            <!-- Chat Section -->
            <div class="chat-section">
                <h2>Real-Time Chat</h2>
                <ul id="chat-messages">
                    <!-- Aici vor fi afișate mesajele -->
                    <?php
                    // Afisăm cele mai recente 10 mesaje
                    if (mysqli_num_rows($message_result) > 0) {
                        while ($message_row = mysqli_fetch_assoc($message_result)) {
                            echo "<li>{$message_row['firstname']} {$message_row['lastname']}: {$message_row['message']}</li>";
                        }
                    } else {
                        echo "<li>No messages yet</li>";
                    }
                    ?>
                </ul>
                <!-- Formular pentru trimiterea unui mesaj -->
                <form id="message-form">
                    <input type="text" id="message-input" name="message" placeholder="Type your message here...">
                    <button type="submit" id="send-button">Send</button>
                </form>
            </div>
            <!-- End Chat Section -->
        </div>
        <!-- End Main Content -->

        <!-- Profile Section -->
        <?php include 'partials/profile.php'; ?>
        <!-- End Profile Section -->
    </div>
</div>
<!-- End Dashboard -->

<!-- JavaScript -->
<script>
document.addEventListener('DOMContentLoaded', function () {
    const form = document.getElementById('message-form');
    const messagesList = document.getElementById('chat-messages');

    form.addEventListener('submit', function (event) {
        event.preventDefault();

        const messageInput = document.getElementById('message-input').value;

        if (messageInput.trim() !== '') {
            const formData = new FormData();
            formData.append('recipient_id', 1); // hardcodat pentru exemplu, poți modifica această valoare
            formData.append('message', messageInput);

            fetch('<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                // Afiseaza mesajul trimis în timp real
                const listItem = document.createElement('li');
                listItem.textContent = data.message;
                // Adaugăm mesajul la începutul listei
                messagesList.insertBefore(listItem, messagesList.firstChild);

                // Goleste inputul pentru mesaj
                document.getElementById('message-input').value = '';
            })
            .catch(error => console.error('Error:', error));
        }
    });

    // Actualizare automată a mesajelor la fiecare 5 secunde
    setInterval(function() {
        fetchMessages();
    }, 5000);

    function fetchMessages() {
        fetch('fetch_messages.php')
        .then(response => response.json())
        .then(data => {
            // Sterge mesajele actuale
            messagesList.innerHTML = '';

            // Afiseaza mesajele noi
            data.messages.forEach(message => {
                const listItem = document.createElement('li');
                listItem.textContent = `${message.firstname} ${message.lastname}: ${message.message}`;
                // Adaugăm mesajul la începutul listei
                messagesList.insertBefore(listItem, messagesList.firstChild);
            });
        })
        .catch(error => console.error('Error:', error));
    }
});


</script>

<!-- Ion Icons Js -->
<script type="module" src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.esm.js"></script>
<script nomodule src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.js"></script>
</body>
</html>
