<?php
include 'partials/header.php';

// Verificăm dacă utilizatorul este autentificat
if (!isset($_SESSION['user-id'])) {
    // Dacă utilizatorul nu este autentificat, îl redirecționăm către pagina de autentificare
    header('Location: signin.php');
    exit();
}

$user_id = $_SESSION['user-id'];

// Interogare pentru a obține informațiile utilizatorului din baza de date
$user_query = "SELECT firstname, lastname, grad FROM users WHERE id = ?";
$stmt = mysqli_prepare($connection, $user_query);
mysqli_stmt_bind_param($stmt, "i", $user_id);
mysqli_stmt_execute($stmt);
$user_result = mysqli_stmt_get_result($stmt);

// Verificăm dacă am obținut un rând rezultat
if ($user_row = mysqli_fetch_assoc($user_result)) {
    // Extragem numele și gradul utilizatorului
    $firstname = $user_row['firstname'];
    $lastname = $user_row['lastname'];
    $grad = $user_row['grad'];
}

// Interogare pentru a obține feedback-ul utilizatorului din baza de date pentru anul 2022
$feedback_query_2022 = "SELECT * FROM Feedback WHERE An = 2022";
$feedback_result_2022 = mysqli_query($connection, $feedback_query_2022);

// Interogare pentru a obține feedback-ul utilizatorului din baza de date pentru anul 2023
$feedback_query_2023 = "SELECT * FROM Feedback WHERE An = 2023";
$feedback_result_2023 = mysqli_query($connection, $feedback_query_2023);

// Inițializăm array-urile pentru valorile feedback-ului pe lună
$feedback_values_2022 = [];
$feedback_values_2023 = [];

// Parcurgem rezultatele și extragem valorile feedback-ului pentru fiecare lună în 2022
while ($row = mysqli_fetch_assoc($feedback_result_2022)) {
    $feedback_values_2022[] = $row;
}

// Parcurgem rezultatele și extragem valorile feedback-ului pentru fiecare lună în 2023
while ($row = mysqli_fetch_assoc($feedback_result_2023)) {
    $feedback_values_2023[] = $row;
}
// Interogare pentru a obține informațiile utilizatorului și calea către imaginea de profil din baza de date
$user_query = "SELECT firstname, lastname, grad, image_profile FROM users WHERE id = ?";
$stmt = mysqli_prepare($connection, $user_query);
mysqli_stmt_bind_param($stmt, "i", $user_id);
mysqli_stmt_execute($stmt);
$user_result = mysqli_stmt_get_result($stmt);

// Verificăm dacă am obținut un rând rezultat
if ($user_row = mysqli_fetch_assoc($user_result)) {
    // Extragem numele, gradul și calea către imaginea de profil a utilizatorului
    $firstname = $user_row['firstname'];
    $lastname = $user_row['lastname'];
    $grad = $user_row['grad'];
    $user_profile_image = $user_row['image_profile'];
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Feedback Chart</title>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
            <style>

        .select-container {
            margin-bottom: 20px;
        }

        .select-container label,
        .select-container select {
            font-size: 18px;
            color: #333;
        }

        .select-container select {
            padding: 8px;
            border-radius: 5px;
            border: 1px solid #ccc;
            background-color: #fff;
            transition: border-color 0.3s;
        }

        .select-container select:hover,
        .select-container select:focus {
            border-color: #6a0dad; /* Culorile mov */
        }

        .back-button {
            background-color: #6a0dad;
            color: #fff;
            border: none;
            border-radius: 5px;
            padding: 10px 20px;
            font-size: 16px;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        .back-button:hover {
            background-color: #4b0872; /* O nuanta mai inchisa de mov */
        }

        /* Stilizare pentru butonul de încărcare a imaginii */
        .upload-button {
            margin-top: 20px;
            padding: 3px 8px;
            /* Culoare de fundal a butonului */
            color: white; /* Culoare text buton */
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s ease; /* Tranzitie pentru culoarea de fundal */
        }
 #upload-btn {
        display: none;
    }
        /* Stilizare pentru hover pe butonul de încărcare a imaginii */
        .upload-button:hover {
            background-color: #0056b3; /* Culoare de fundal a butonului la hover */
        }
  #submit-btn {
        display: none;
    }
        /* Ascunde inputul pentru încărcarea fișierului */
        #file-input {
            display: none;
        }
    </style>
</head>
<body>
    <!-- Dashboard -->
    <div class="dashboard">
        <!-- Main Content -->
        <div class="main-content">
            <!-- Head -->
            <div class="head flex">
                <button class="back-button" onclick="window.location.href = 'index.php';">Inapoi</button>
                <h1>Feedback Chart</h1>
                <div class="box flex">
                    <ion-icon name="search-outline"></ion-icon>
                </div>
            </div>
            <!-- End Head -->

            <!-- Stats -->
            <div class="stats flex">
                <div class="stats-box">
                    <h2 class="heading">Feedback pe lună în 2022 și 2023</h2>
                    <canvas id="feedbackChart" width="800" height="400"></canvas>
                </div>
            </div>
            <!-- End Stats -->
        </div>
        <!-- End Main Content -->

<!-- Profile -->
<div class="profile">
    <div class="title flex">
        <h2 class="heading">Profile</h2>
    </div>
    <div class="user">
        <!-- Afișarea imaginii de profil -->
        <?php
        if (!empty($user_profile_image)) {
            echo '<img src="' . htmlspecialchars($user_profile_image) . '" alt="Profile Picture">';
        } else {
            // Dacă nu există o imagine de profil setată, afișăm o imagine de profil implicită
            echo '<img src="default-profile-image.jpg" alt="Profile Picture">';
        }
        ?>
        <!-- End Afișarea imaginii de profil -->

        <!-- Formular pentru încărcarea imaginii -->
        <form action="upload.php" method="post" enctype="multipart/form-data">
            <input type="file" name="file" id="file-input" accept="image/*">
            <label for="file-input" class="upload-button" id="upload-button">Schimba imaginea</label>
            <!-- Actualizăm butonul de submit pentru a avea un id specific -->
            <input type="submit" id="submit-btn" value="Submit">
        </form>
        <!-- End Formular pentru încărcarea imaginii -->

        <h2><?php echo htmlspecialchars($firstname . ' ' . $lastname); ?></h2>

        <?php
        // Afișăm imaginea corespunzătoare gradului utilizatorului
        if ($grad === "Administrator") {
            echo '<h3><a href="' . ROOT_URL . 'announcement.php">Admin Panel</a></h3>';
        }
        ?>

        <!-- Afișăm imaginea corespunzătoare gradului utilizatorului -->
        <?php
        if ($grad === "Administrator") {
            echo '<div class="icon grad-icon" style="margin-left: 100px;"><img src="rank/Management.png" alt="Administrator" style="width: 156px; height: 35px;"></div>';
        } else if ($grad === "Departament Financiar") {
            echo '<div class="icon grad-icon" style="margin-left: 100px;"><img src="rank/Staff.png" alt="Departament Financiar" style="width: 156px; height: 35px;"></div>';
        } else {
            echo '<div class="icon grad-icon" style="margin-left: 100px;"><img src="rank/Member.png" alt="Users" style="width: 156px; height: 35px;"></div>';
        }
        ?>
       
        <h3><a href="<?= ROOT_URL ?>logout.php">Logout</a></h3>
    </div>
    <div class="activities">
        <div class="title flex">
            <h2 class="heading">Activity</h2>
            <p>View All ></p>
        </div>
    </div>
</div>
<!-- End Profile -->
    </div>
    <!-- End Dashboard -->

    <script>
        // Data for feedback chart
        var feedbackData = {
            labels: ['Ianuarie', 'Februarie', 'Martie', 'Aprilie', 'Mai', 'Iunie', 'Iulie', 'August', 'Septembrie', 'Octombrie', 'Noiembrie', 'Decembrie'],
            datasets: [{
                label: 'Feedback 2022',
                data: [<?php foreach ($feedback_values_2022 as $feedback) { echo implode(",", array_slice($feedback, 2)); } ?>],
                backgroundColor: function(context) {
                    var index = context.dataIndex;
                    var value = context.dataset.data[index];
                    return value < 3 ? 'rgba(255, 99, 132, 0.2)' : 'rgba(75, 192, 192, 0.2)';
                },
                borderColor: function(context) {
                    var index = context.dataIndex;
                    var value = context.dataset.data[index];
                    return value < 3 ? 'rgba(255, 99, 132, 1)' : 'rgba(75, 192, 192, 1)';
                },
                borderWidth: 1
            }, {
                label: 'Feedback 2023',
                data: [<?php foreach ($feedback_values_2023 as $feedback) { echo implode(",", array_slice($feedback, 2)); } ?>],
                backgroundColor: function(context) {
                    var index = context.dataIndex;
                    var value = context.dataset.data[index];
                    return value < 3 ? 'rgba(255, 99, 132, 0.2)' : 'rgba(75, 192, 192, 0.2)';
                },
                borderColor: function(context) {
                    var index = context.dataIndex;
                    var value = context.dataset.data[index];
                    return value < 3 ? 'rgba(255, 99, 132, 1)' : 'rgba(75, 192, 192, 1)';
                },
                borderWidth: 1
            }]
        };

        var feedbackOptions = {
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        };

        // Create and render the feedback chart
        var feedbackChart = document.getElementById('feedbackChart').getContext('2d');
        new Chart(feedbackChart, {
            type: 'bar',
            data: feedbackData,
            options: feedbackOptions
        });
    </script>
     <script>
    // Așteptăm ca documentul să se încarce complet
    document.addEventListener("DOMContentLoaded", function () {
        // Selectăm input-ul pentru încărcarea fișierului
        var fileInput = document.getElementById('file-input');

        // Selectăm butonul de submit
        var submitButton = document.getElementById('submit-btn');

        // Adăugăm un eveniment pentru când utilizatorul selectează un fișier
        fileInput.addEventListener('change', function () {
            // Verificăm dacă s-a selectat un fișier
            if (fileInput.files.length > 0) {
                // Simulăm un click pe butonul de submit
                submitButton.click();
            }
        });
    });


</script>
</body>
</html>
