<?php
include 'partials/header.php';

// Verificăm dacă utilizatorul este autentificat
if (!isset($_SESSION['user-id'])) {
    // Dacă utilizatorul nu este autentificat, îl redirecționăm către pagina de autentificare
    header('Location: signin.php');
    exit();
}

$user_id = $_SESSION['user-id'];

// Interogare pentru a obține informațiile utilizatorului din baza de date
$user_query = "SELECT firstname, lastname, grad FROM users WHERE id = ?";
$stmt = mysqli_prepare($connection, $user_query);
mysqli_stmt_bind_param($stmt, "i", $user_id);
mysqli_stmt_execute($stmt);
$user_result = mysqli_stmt_get_result($stmt);

// Verificăm dacă am obținut un rând rezultat
if ($user_row = mysqli_fetch_assoc($user_result)) {
    // Extragem numele și gradul utilizatorului
    $firstname = $user_row['firstname'];
    $lastname = $user_row['lastname'];
    $grad = $user_row['grad'];
}

// Interogare pentru a obține datele din tabela flota_transporturi
$transport_query = "SELECT id, litri_pe_100_km FROM flota_transporturi";
$transport_result = mysqli_query($connection, $transport_query);

// Inițializăm array-urile pentru intervalul de litri și numărul de mașini
$litri_intervals = ['1-5', '6-8', '12+'];
$litri_counts = [0, 0, 0];

// Parcurgem rezultatele și actualizăm numărul de mașini în fiecare interval de litri
while ($row = mysqli_fetch_assoc($transport_result)) {
    $litri = $row['litri_pe_100_km'];
    if ($litri >= 1 && $litri <= 5) {
        $litri_counts[0]++;
    } elseif ($litri >= 6 && $litri <= 8) {
        $litri_counts[1]++;
    } else {
        $litri_counts[2]++;
    }
}

// Convertim array-urile în format JSON pentru a le folosi în JavaScript pentru consumul mediu de litri și numărul de mașini
$litri_intervals_json = json_encode($litri_intervals);
$litri_counts_json = json_encode($litri_counts);
// La fel pentru graficul de întârzieri
// Interogare pentru a obține datele de întârzieri (presupunând că sunt într-o tabelă numită 'intarzieri')
$intarzieri_query = "SELECT luna, an, numar_intarzieri FROM intarzieri";
$intarzieri_result = mysqli_query($connection, $intarzieri_query);

// Inițializăm array-urile pentru luni și numărul de întârzieri
$luni = ['Ianuarie', 'Februarie', 'Martie', 'Aprilie', 'Mai', 'Iunie', 'Iulie', 'August', 'Septembrie', 'Octombrie', 'Noiembrie', 'Decembrie'];
$intarzieri_an1 = [];
$intarzieri_an2 = [];
$intarzieri_an3 = [];

// Parcurgem rezultatele și actualizăm numărul de întârzieri pentru fiecare an
while ($row = mysqli_fetch_assoc($intarzieri_result)) {
    $luna = $row['luna'];
    $an = $row['an'];
    $numar_intarzieri = $row['numar_intarzieri'];
    
    if ($an == 2020) {
        $intarzieri_an1[$luna] = $numar_intarzieri;
    } elseif ($an == 2021) {
        $intarzieri_an2[$luna] = $numar_intarzieri;
    } elseif ($an == 2022) {
        $intarzieri_an3[$luna] = $numar_intarzieri;
    }
}

// Convertim array-urile în format JSON pentru a le folosi în JavaScript pentru graficul de întârzieri
$intarzieri_an1_json = json_encode(array_values($intarzieri_an1)); // valorile pentru anul 2020
$intarzieri_an2_json = json_encode(array_values($intarzieri_an2)); // valorile pentru anul 2021
$intarzieri_an3_json = json_encode(array_values($intarzieri_an3)); // valorile pentru anul 2022

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Consum Mediu Litri din totalul flotei</title>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        /* Base */

        *,
        *::after,
        *::before {
            box-sizing: border-box;
            padding: 0;
            margin: 0;
            font-family: "Time New Roman", sans-serif;
        }

        body {
            background: #1d243c;
            color: #e7e9fb;
            font-size: 62.5%;
        }

        /* End Base */

        .container {
            max-width: 800px;
            margin: 50px auto;
            background-color: #ebebeb;
            border-radius: 10px;
            padding: 20px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        h1 {
            font-size: 2.2rem;
            font-weight: 600;
            color: #fff;
            text-align: center;
            margin-bottom: 20px;
        }

        .chart-container {
            margin-top: 20px;
            position: relative;
            height: 300px;
            width: 100%;
        }

        canvas {
            max-width: 100%;
            height: auto;
        }

        /* End Base */

        /* Menu */
        .menu {
            flex: 0 0 8%;
            min-height: 80rem;
            background: #898da5;
            justify-content: space-between;
            padding: 2rem;
        }

        .menu .icon:hover,
        .menu .logo .icon {
            background: linear-gradient(to right bottom, #faad72, #f89456);
            color: #2c1923;
            border-radius: 2px;
            transition: all 0.6s ease-out;
        }
        /* End Menu */

        /* Main Content */
        .main-content {
            padding: 3rem;
            width: 76%;
        }

        .box {
            padding: 10px;
            background: #5a5f7a;
            font-size: 1.8rem;
            font-weight: 500;
            color: #e6e3e5;
            cursor: pointer;
            margin-bottom: 20px;
        }

        .stats {
            background: #2a314e;
            margin-top: 4rem;
            padding: 2rem 1rem;
            font-size: 1.6rem;
            justify-content: space-between;
        }

        .stats-box {
            min-height: 30rem;
            padding: 2rem 1rem;
        }

        .stats-box .heading {
            margin-bottom: 2rem;
            color: #fcfcfc;
        }

        .earning {
            background: hsl(0, 0%, 100%);
            width: 38%;
        }

        .earning-amount {
            font-size: 2rem;
            color: #fff;
            margin-bottom: 10px;
        }

        .earning-icon {
            font-size: 4rem;
            color: #3f2532;
            background: linear-gradient(to right bottom, #faad72, #f89456);
            padding: 15px;
            border-radius: 50%;
            margin-bottom: 10px;
        }

        .top-selling-products {
            text-align: left;
            font-size: 1.8rem;
            padding: 7px 0;
            color: #fff;
        }

        .top-selling-products th {
            background: #2c253f;
        }

        .top-selling-products th,
        .top-selling-products td {
            padding: 10px 8px;
        }

        .product-name p {
            margin-left: 10px;
            color: #ccc;
        }

        .product-name.iphone .icon {
            background: #f89456;
        }

        .product-name.windows .icon {
            background: #dc9afc;
        }
        /* End Main Content */

        /* Profile */
        .profile {
            background: #ffffff5f;
            padding: 2rem;
            flex: 1;
        }

        .user
{
    color: #000000;
    text-align: center;
    margin: 3rem 0 5rem 0;
}

.user img {
    width: 100px;
    height: 100px;
    display: block;
    margin: 0 auto;
}

.user h2 {
    font-size: 2rem;
    margin: 8px 0;
    color: #fcfcfc;
}

.activities {
    margin: 10px 0;
    font-size: 14px;
    color: #ccc;
}

.activity {
    justify-content: flex-start;
    font-size: 14px;
    margin: 2rem 0;
}

.activity h2 {
    font-size: 12px;
    font-weight: bold;
    color: #fff;
}

.task p {
    color: #ddd;
}

.activity .icon {
    font-size: 3rem;
    width: 40px;
    height: 40px;
    background: #33202c;
    margin: 0 5px 5px 5px;
    border-radius: 50%;
    color: #faad72;
}

.upgrade {
    width: 100%;
    margin: 5rem auto 0 auto;
    background: #33202c;
    padding: 2rem;
    color: #ccc;
    text-align: center;
    font-size: 14px;
}

.upgrade .icon {
    font-size: 8rem;
    color: #ccc;
}

.btn {
    width: 100%;
    margin: 0 auto;
    background: linear-gradient(to right bottom, #faad72, #f89456);
    padding: 2rem 0;
    color: #2f1a27;
    font-size: 2rem;
    font-weight: bold;
    cursor: pointer;
}
/* End Profile */

/* Responsive */
@media (max-width: 1200px) {
    .dashboard {
        width: 100%;
        max-width: 100%;
        margin: 0;
    }
}

@media (max-width: 1180px) {
    html {
        font-size: 50%;
    }
}

@media (max-width: 1050px) {
    html {
        font-size: 50%;
    }
}
@media (max-width: 1000px) {
    .content {
        flex-direction: column;
    }

    .profile {
        width: 40%;
        margin: 3rem auto;
    }

    .main-content {
        width: 100%;
    }

    .title,
    .upgrade {
        display: none;
    }

    .activity {
        justify-content: center;
    }

    .btn {
        width: 60%;
    }
}

@media (max-width: 850px) {
    .menu {
        width: 100%;
        flex-direction: row;
        position: absolute;
        height: 80px;
        min-height: 80px;
    }

    .navigation {
        display: flex;
    }

    .navigation .icon {
        margin: 0 10px;
    }

    .content {
        margin-top: 85px;
    }
}

@media (max-width: 750px) {
    .stats {
        flex-direction: column;
        background: none;
    }

    .sales,
    .earning {
        width: 100%;
        margin: 20px 0;
        background: #3f2532;
    }

    .profile {
        width: 60%;
    }
}

@media (max-width: 650px) {
    .navigation,
    .settings {
        display: none;
    }

    .menu {
        justify-content: center;
    }

    .main-content {
        padding: 1rem;
    }

    .product-stats {
        flex-direction: column;
    }

    .product-sales,
    .top-selling {
        width: 95%;
        padding: 2rem 4rem;
        margin: 20px auto;
    }

    .product-sales {
        width: 60%;
    }
}

@media (max-width: 550px) {
    .product-sales,
    .top-selling {
        width: 100%;
    }

    .product-name .icon {
        display: none;
    }

    .profile {
        width: 85%;
    }

    .menu {
        min-height: 60px;
        height: 60px;
    }
}

@media (max-width: 300px) {
    html {
        font-size: 35%;
    }
}
/* End  Responsive */
    </style>
</head>
<body>
    <div class="container">
        <h1>Consum Mediu Litri din totalul flotei</h1>
        <div class="chart-container">
            <canvas id="consumChart"></canvas>
        </div>
    </div>


   <script>
        // Datele pentru consumul mediu de litri și numărul de mașini
        var litriIntervals = <?php echo $litri_intervals_json; ?>;
        var litriCounts = <?php echo $litri_counts_json; ?>;

        // Desenarea graficului pentru consum
        var ctx1 = document.getElementById('consumChart').getContext('2d');
        var myChart1 = new Chart(ctx1, {
            type: 'bar',
            data: {
                labels: litriIntervals,
                datasets: [{
                    label: 'Consum Litri',
                    data: litriCounts,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.5)', // Roșu
                        'rgba(54, 162, 235, 0.5)', // Albastru
                        'rgba(255, 206, 86, 0.5)'  // Galben
                    ],
                    borderColor: [
                        'rgba(255, 99, 132, 1)',
                        'rgba(54, 162, 235, 1)',
                        'rgba(162, 235, 1)',
'rgba(255, 206, 86, 1)'
],
borderWidth: 1
}]
},
options: {
scales: {
y: {
beginAtZero: true,
grid: {
color: 'rgba(0, 0, 0, 0.1)'
}
},
x: {
grid: {
display: false
}
}
}
}
});
              // Datele pentru graficul de întârzieri
    var luni = <?php echo json_encode($luni); ?>;
    var intarzieri_an1 = <?php echo $intarzieri_an1_json; ?>;
    var intarzieri_an2 = <?php echo $intarzieri_an2_json; ?>;
    var intarzieri_an3 = <?php echo $intarzieri_an3_json; ?>;

    // Desenarea graficului pentru întârzieri
    var ctx2 = document.getElementById('intarzieriChart').getContext('2d');
    var myChart2 = new Chart(ctx2, {
        type: 'line',
        data: {
            labels: luni,
            datasets: [
                {
                    label: '2020',
                    data: intarzieri_an1,
                    borderColor: 'rgba(255, 99, 132, 1)',
                    backgroundColor: 'rgba(255, 99, 132, 0.5)',
                    borderWidth: 1
                },
                {
                    label: '2021',
                    data: intarzieri_an2,
                    borderColor: 'rgba(54, 162, 235, 1)',
                    backgroundColor: 'rgba(54, 162, 235, 0.5)',
                    borderWidth: 1
                },
                {
                    label: '2022',
                    data: intarzieri_an3,
                    borderColor: 'rgba(255, 206, 86, 1)',
                    backgroundColor: 'rgba(255, 206, 86, 0.5)',
                    borderWidth: 1
                }
            ]
        },
        options: {
            scales: {
                y: {
                    beginAtZero: true,
                    grid: {
                        color: 'rgba(0, 0, 0, 0.1)'
                    }
                },
                x: {
                    grid: {
                        display: false
                    }
                }
            }
        }
    });
</script>

</body>
</html>
