<?php
include 'partials/header.php';

// Verificăm dacă utilizatorul este autentificat
if (!isset($_SESSION['user-id'])) {
    // Dacă utilizatorul nu este autentificat, îl redirecționăm către pagina de autentificare
    header('Location: signin.php');
    exit();
}

$user_id = $_SESSION['user-id'];

// Interogare pentru a obține informațiile utilizatorului și calea către imaginea de profil din baza de date
$user_query = "SELECT firstname, lastname, grad, image_profile FROM users WHERE id = ?";
$stmt = mysqli_prepare($connection, $user_query);
mysqli_stmt_bind_param($stmt, "i", $user_id);
mysqli_stmt_execute($stmt);
$user_result = mysqli_stmt_get_result($stmt);

// Verificăm dacă am obținut un rând rezultat
if ($user_row = mysqli_fetch_assoc($user_result)) {
    // Extragem numele, gradul și calea către imaginea de profil a utilizatorului
    $firstname = $user_row['firstname'];
    $lastname = $user_row['lastname'];
    $grad = $user_row['grad'];
    $user_profile_image = $user_row['image_profile'];
}

// Interogare pentru a obține anunțurile din baza de date
$announcements_query = "SELECT title, content, publication_date FROM announcements ORDER BY publication_date DESC LIMIT 5";
$announcements_result = mysqli_query($connection, $announcements_query);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <!-- CSS -->
    <link rel="stylesheet" href="css/style.css">
    <style>

        /* Stilizare pentru fiecare anunț */
        .announcements li {
            margin-bottom: 20px;
            padding: 10px;
            background-color: white; /* Fundal alb 50% transparent */
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.4); /* Umbră */
            position: relative;
            text-align: center;
        }

        /* Stilizare pentru titlul anunțului */
        .announcements h3 {
            color: black; /* Culoare text mov */
            margin-top: 0;
            font-size: 21px;
        }

        /* Stilizare pentru conținutul anunțului */
        .announcements p {
            color: #333; /* Culoare text */
            margin-bottom: 5px;
            font-size: 16px;
        }

        /* Stilizare pentru data publicării anunțului */
        .announcements .publication-date {
            color: #666; /* Culoare text gri */
            font-style: italic;
        }

        .publication-date{
            font-size: 9px;
        }

        /* Stilizare pentru pictograma anunțului */
        .announcement-icon {
            position: absolute;
            top: -10px;
            right: -10px;
            width: 30px;
            height: 30px;
            background-image: url('announcement-icon.png'); /* Imaginea pictogramei */
            background-size: cover;
        }

        /* Stilizare pentru butonul de încărcare a imaginii */
        .upload-button {
            margin-top: 20px;
            padding: 3px 8px;
            /* Culoare de fundal a butonului */
            color: white; /* Culoare text buton */
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s ease; /* Tranzitie pentru culoarea de fundal */
        }
 #upload-btn {
        display: none;
    }
        /* Stilizare pentru hover pe butonul de încărcare a imaginii */
        .upload-button:hover {
            background-color: #0056b3; /* Culoare de fundal a butonului la hover */
        }
  #submit-btn {
        display: none;
    }
        /* Ascunde inputul pentru încărcarea fișierului */
        #file-input {
            display: none;
        }
    </style>
</head>
<body>
    <!-- Dashboard -->
    <div class="dashboard">
        <!-- Menu -->
        <div class="menu flex-c">
            <div class="logo">
                <div class="icon">
                    <ion-icon name="logo-trello"></ion-icon>
                </div>
            </div>
            <div class="navigation">
                <div class="icon">
                    <a href="feedback.php" class="icon" style="text-decoration: none; color: inherit;">
                        <div>
                            <ion-icon name="filter-circle-outline"></ion-icon>
                        </div>
                    </a>
                </div>
<div class="icon">
    <a href="flota_transport.php" class="icon" style="text-decoration: none; color: inherit;">
        <ion-icon name="file-tray-full-outline"></ion-icon>
    </a>
</div>

                <div class="icon">
                    <a href="form.php" class="icon" style="text-decoration: none; color: inherit;">
                        <ion-icon name="mail-unread-outline"></ion-icon>
                    </a>
                </div>
                <div class="icon">
                    <a href="statistics.php" class="icon" style="text-decoration: none; color: inherit;">
                        <div>
                            <ion-icon name="pulse-outline"></ion-icon>
                        </div>
                    </a>
                </div>
                <div class="icon">
                    <ion-icon name="storefront-outline"></ion-icon>
                </div>
            </div>
            <div class="settings">
                <div class="icon">
                    <ion-icon name="settings-outline"></ion-icon>
                </div>
            </div>
        </div>
        <!-- End Menu -->

        <div class="content">
            <!-- Main Content -->
            <div class="main-content">
                <!-- Head -->
                <div class="head flex">
                    <h1>Ce mai e nou 👋</h1>
                    <div class="box flex">
                        <ion-icon name="search-outline"></ion-icon>
                    </div>
                </div>
                <!-- End Head -->

                <!-- Announcements -->
                <div class="announcements">
                    <ul>
                        <?php while ($announcement_row = mysqli_fetch_assoc($announcements_result)) { ?>
                            <li>
                                <div class="announcement-icon"></div> <!-- Pictograma anunțului -->
                                <h3><?php echo htmlspecialchars($announcement_row['title']); ?></h3>
                                <p><?php echo htmlspecialchars($announcement_row['content']); ?></p>
                                <p class="publication-date"><?php echo htmlspecialchars($announcement_row['publication_date']); ?></p>
                            </li>
                        <?php } ?>
                    </ul>
                </div>
                <!-- End Announcements -->

            </div>
            <!-- End Main Content -->

<!-- Profile -->
<div class="profile">
    <div class="title flex">
        <h2 class="heading">Profile</h2>
    </div>
    <div class="user">
        <!-- Afișarea imaginii de profil -->
        <?php
        if (!empty($user_profile_image)) {
            echo '<img src="' . htmlspecialchars($user_profile_image) . '" alt="Profile Picture">';
        } else {
            // Dacă nu există o imagine de profil setată, afișăm o imagine de profil implicită
            echo '<img src="default-profile-image.jpg" alt="Profile Picture">';
        }
        ?>
        <!-- End Afișarea imaginii de profil -->

        <!-- Formular pentru încărcarea imaginii -->
        <form action="upload.php" method="post" enctype="multipart/form-data">
            <input type="file" name="file" id="file-input" accept="image/*">
            <label for="file-input" class="upload-button" id="upload-button">Schimba imaginea</label>
            <!-- Actualizăm butonul de submit pentru a avea un id specific -->
            <input type="submit" id="submit-btn" value="Submit">
        </form>
        <!-- End Formular pentru încărcarea imaginii -->

        <h2><?php echo htmlspecialchars($firstname . ' ' . $lastname); ?></h2>

        <?php
        // Afișăm imaginea corespunzătoare gradului utilizatorului
        if ($grad === "Administrator") {
            echo '<h3><a href="' . ROOT_URL . 'announcement.php">Admin Panel</a></h3>';
        }
        ?>

        <!-- Afișăm imaginea corespunzătoare gradului utilizatorului -->
        <?php
        if ($grad === "Administrator") {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Management.png" alt="Administrator" style="width: 156px; height: 35px;"></div>';
        } else if ($grad === "Departament Financiar") {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Staff.png" alt="Departament Financiar" style="width: 156px; height: 35px;"></div>';
        } else {
            echo '<div class="icon grad-icon" style="margin-left: 90px;"><img src="rank/Member.png" alt="Users" style="width: 156px; height: 35px;"></div>';
        }
        ?>
       
        <h3><a href="<?= ROOT_URL ?>logout.php">Logout</a></h3>
    </div>
    <div class="activities">
        <div class="title flex">
            <h2 class="heading">Activity</h2>
            <p>View All ></p>
        </div>
    </div>
</div>
<!-- End Profile -->

        </div>
    </div>
    <!-- End Dashboard -->
<!-- Adăugați următorul script JavaScript înainte de încheierea tag-ului </body> -->
<!-- Adăugați următorul script JavaScript înainte de încheierea tag-ului </body> -->
<!-- Adăugați următorul script JavaScript înainte de încheierea tag-ului </body> -->
<script>
    // Așteptăm ca documentul să se încarce complet
    document.addEventListener("DOMContentLoaded", function () {
        // Selectăm input-ul pentru încărcarea fișierului
        var fileInput = document.getElementById('file-input');

        // Selectăm butonul de submit
        var submitButton = document.getElementById('submit-btn');

        // Adăugăm un eveniment pentru când utilizatorul selectează un fișier
        fileInput.addEventListener('change', function () {
            // Verificăm dacă s-a selectat un fișier
            if (fileInput.files.length > 0) {
                // Simulăm un click pe butonul de submit
                submitButton.click();
            }
        });
    });


</script>



    <!-- Ion Icons Js -->
    <script type="module" src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.esm.js"></script>
    <script nomodule src="https://cdn.jsdelivr.net/npm/@ionic/core/dist/ionic/ionic.js"></script>
</body>
</html>
