<?php

// Definim datele JSON ca un șir de caractere
$json_data_string = '[
  {
    "an": 2020,
    "luna": 1,
    "intarzierea_medie": 15.30
  },
  {
    "an": 2020,
    "luna": 2,
    "intarzierea_medie": 14.50
  },
  {
    "an": 2020,
    "luna": 3,
    "intarzierea_medie": 16.20
  },
  {
    "an": 2020,
    "luna": 4,
    "intarzierea_medie": 17.80
  },
  {
    "an": 2020,
    "luna": 5,
    "intarzierea_medie": 18.50
  },
  {
    "an": 2020,
    "luna": 6,
    "intarzierea_medie": 19.70
  },
  {
    "an": 2020,
    "luna": 7,
    "intarzierea_medie": 20.10
  },
  {
    "an": 2020,
    "luna": 8,
    "intarzierea_medie": 21.40
  },
  {
    "an": 2020,
    "luna": 9,
    "intarzierea_medie": 22.60
  },
  {
    "an": 2020,
    "luna": 10,
    "intarzierea_medie": 23.80
  },
  {
    "an": 2020,
    "luna": 11,
    "intarzierea_medie": 24.50
  },
  {
    "an": 2020,
    "luna": 12,
    "intarzierea_medie": 25.30
  },
  {
    "an": 2021,
    "luna": 1,
    "intarzierea_medie": 16.10
  },
  {
    "an": 2021,
    "luna": 2,
    "intarzierea_medie": 15.70
  },
  {
    "an": 2021,
    "luna": 3,
    "intarzierea_medie": 11.20
  },
  {
    "an": 2021,
    "luna": 4,
    "intarzierea_medie": 11.30
  },
  {
    "an": 2021,
    "luna": 5,
    "intarzierea_medie": 11.60
  },
  {
    "an": 2021,
    "luna": 6,
    "intarzierea_medie": 1.90
  },
  {
    "an": 2021,
    "luna": 7,
    "intarzierea_medie": 1.30
  },
  {
    "an": 2021,
    "luna": 8,
    "intarzierea_medie": 22.50
  },
  {
    "an": 2021,
    "luna": 9,
    "intarzierea_medie": 23.70
  },
  {
    "an": 2021,
    "luna": 10,
    "intarzierea_medie": 24.20
  },
  {
    "an": 2021,
    "luna": 11,
    "intarzierea_medie": 25.10
  },
  {
    "an": 2021,
    "luna": 12,
    "intarzierea_medie": 26.00
  },
  {
    "an": 2022,
    "luna": 1,
    "intarzierea_medie": 16.50
  }
]';
// Decodificăm șirul JSON într-un array asociativ
$json_data = json_decode($json_data_string, true);

// Verificăm dacă există date în array-ul JSON
if (!empty($json_data)) {
    // Creăm un array separat pentru fiecare an
    $intarzieri_an_2020 = [];
    $intarzieri_an_2021 = [];
    $intarzieri_an_2022 = [];
    
    // Iterăm prin datele JSON pentru a extrage datele necesare
    foreach ($json_data as $item) {
        $an = $item['an'];
        $intarzierea_medie = $item['intarzierea_medie'];

        // Adăugăm valoarea de întârziere medie în array-ul asociat anului respectiv
        switch ($an) {
            case 2020:
                $intarzieri_an_2020[] = $intarzierea_medie;
                break;
            case 2021:
                $intarzieri_an_2021[] = $intarzierea_medie;
                break;
            case 2022:
                $intarzieri_an_2022[] = $intarzierea_medie;
                break;
            default:
                break;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Graph</title>
    <!-- Adaugăm biblioteca Chart.js pentru a desena graficul -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<body>
    <div style="width: 75%;">
        <!-- Meniu select pentru a selecta anul -->
        <label for="selectYear">Selectează anul:</label>
        <select id="selectYear" onchange="drawSelectedYearChart()">
            <option value="2020">2020</option>
            <option value="2021">2021</option>
            <option value="2022">2022</option>
        </select>
    </div>

    <div style="width: 75%;">
        <!-- Aici va fi afișat graficul -->
        <canvas id="myChart"></canvas>
    </div>

    <script>
    // Definim funcția care va desena graficul pentru anul selectat
    function drawSelectedYearChart() {
        var selectElement = document.getElementById('selectYear');
        var selectedYear = selectElement.value;
        var jsonData = <?php echo json_encode($json_data); ?>;
        
        // Filtrăm datele pentru anul selectat
        var filteredData = jsonData.filter(function(item) {
            return item.an == selectedYear;
        });
        
        // Extragem luni și intarzierile medii pentru grafic
        var labels = filteredData.map(function(item) {
            return item.luna;
        });
        var delays = filteredData.map(function(item) {
            return item.intarzierea_medie;
        });
        
        // Obținem contextul pentru canvas
        var ctx = document.getElementById('myChart').getContext('2d');
        
        // Verificăm dacă există deja un grafic desenat și îl ștergem
        if(window.myChart != null){
            window.myChart.destroy();
        }
        
        // Inițializăm graficul
        window.myChart = new Chart(ctx, {
            type: 'line',
            data: {
                labels: labels,
                datasets: [{
                    label: 'Intârzierea medie',
                    data: delays,
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                scales: {
                    y: {
                        beginAtZero: true
                    }
                }
            }
        });
    }
    
    // Afișăm graficul pentru anul 2020 la încărcarea paginii
    drawSelectedYearChart();
    </script>
</body>
</html>